@@ -46,14 +46,12 @@ class LogGroup(argclass.Group):
     )
 
 
-class PeriodicGroup(argclass.Group):
+class CollectorGroup(argclass.Group):
     interval: int
     delay: int = 0
-
-
-class CollectorGroup(PeriodicGroup):
     skip_interface: FrozenSet[str] = argclass.Argument(
         nargs=argclass.Nargs.ONE_OR_MORE, converter=frozenset,
+        default="[]"
     )
 
 
@@ -64,7 +62,7 @@ class Parser(argclass.Parser):
         title="HTTP server options",
         defaults=dict(address="127.0.0.1", port=8080),
     )
-    collector = PeriodicGroup(
+    collector = CollectorGroup(
         title="Collector Service options",
         defaults=dict(interval=30),
     )
@@ -407,6 +405,7 @@ class LimitsCPUEffectiveCollector(ContainerVirtualCollector):
 
 
 class StateCollector(ContainerVirtualCollector):
+    SKIP_INTERFACES: FrozenSet[str] = frozenset([])
     METRIC_CPU = Metric(
         namespace="lxd",
         subsystem="container",
@@ -563,6 +562,15 @@ class StateCollector(ContainerVirtualCollector):
             return
 
         for name, usage in state["network"].items():
+            skipping = False
+            for skip in self.SKIP_INTERFACES:
+                if name.startswith(skip):
+                    skipping = True
+                    break
+
+            if skipping:
+                continue
+
             self.METRIC_NETWORK_RX.labels(
                 device=name, **labels
             ).set(usage["counters"]["bytes_received"])
@@ -797,6 +805,7 @@ class CollectorService(PeriodicService):
     lxd_cert: Path
     client_cert: Path
     client_key: Path
+    skip_interfaces: FrozenSet[str]
 
     _ssl_context: ssl.SSLContext
     _client: aiohttp.ClientSession
@@ -916,6 +925,12 @@ def main():
         level=arguments.log.level,
     )
 
+    logging.info(
+        "Network interfaces starts with %r will be skipped",
+        list(arguments.collector.skip_interface)
+    )
+    StateCollector.SKIP_INTERFACES = arguments.collector.skip_interface
+
     services = [
         MetricsAPI(
             address=arguments.http.address,
